Struct wpilib::encoder::Encoder

source ·
pub struct Encoder { /* private fields */ }
An encoder.

Uses quadrature on two separate channels to read the distance and direction travelled by a shaft. All integration is done by the FPGA.

Implementations

Create a new encoder given two channels and an encoding type, returning an error if initialization fails.

Get the FPGA index of this encoder.

Get the current value read by this encoder, with any scaling factors applied.

Get the raw value of this encoder, without any scaling factors.

Get the current scaling factor for this encoder.

Get the current (estimated) speed this encoder is travelling at.

Set the minimum rate that this encoder must be moving at to be considered “moving”.

Reset the count of this encoder.